Command-line interface
==========================

Locan is designed as a Python library.
Full functionality of the package is accessible through Python scripts or Jupyter notebooks.

A command-line interface is provided for selected routines.
It is accessible from any terminal by the base command ``locan`` and provides a number of compound commands.
For a complete description of available commands see  documentation of the :mod:`locan.scripts` module or
look up command-line help using ``locan -h``.


